==> py-subversion-1.1.3p0.tgz: lib/python2.3/site-packages/libsvn/fs.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _fs

def _swig_setattr(self,class_type,name,value):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    self.__dict__[name] = value

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


import delta

svn_fs_version = _fs.svn_fs_version
SVN_FS_CONFIG_BDB_TXN_NOSYNC = _fs.SVN_FS_CONFIG_BDB_TXN_NOSYNC
SVN_FS_CONFIG_BDB_LOG_AUTOREMOVE = _fs.SVN_FS_CONFIG_BDB_LOG_AUTOREMOVE
SVN_FS_CONFIG_FS_TYPE = _fs.SVN_FS_CONFIG_FS_TYPE
SVN_FS_TYPE_BDB = _fs.SVN_FS_TYPE_BDB
SVN_FS_TYPE_FSFS = _fs.SVN_FS_TYPE_FSFS

svn_fs_set_warning_func = _fs.svn_fs_set_warning_func

svn_fs_create = _fs.svn_fs_create

svn_fs_open = _fs.svn_fs_open

svn_fs_path = _fs.svn_fs_path

svn_fs_delete_fs = _fs.svn_fs_delete_fs

svn_fs_hotcopy = _fs.svn_fs_hotcopy

svn_fs_set_berkeley_errcall = _fs.svn_fs_set_berkeley_errcall

svn_fs_berkeley_recover = _fs.svn_fs_berkeley_recover

svn_fs_berkeley_logfiles = _fs.svn_fs_berkeley_logfiles

svn_fs_new = _fs.svn_fs_new

svn_fs_create_berkeley = _fs.svn_fs_create_berkeley

svn_fs_open_berkeley = _fs.svn_fs_open_berkeley

svn_fs_berkeley_path = _fs.svn_fs_berkeley_path

svn_fs_delete_berkeley = _fs.svn_fs_delete_berkeley

svn_fs_hotcopy_berkeley = _fs.svn_fs_hotcopy_berkeley

svn_fs_compare_ids = _fs.svn_fs_compare_ids

svn_fs_check_related = _fs.svn_fs_check_related

svn_fs_parse_id = _fs.svn_fs_parse_id

svn_fs_unparse_id = _fs.svn_fs_unparse_id

svn_fs_begin_txn = _fs.svn_fs_begin_txn

svn_fs_commit_txn = _fs.svn_fs_commit_txn

svn_fs_abort_txn = _fs.svn_fs_abort_txn

svn_fs_purge_txn = _fs.svn_fs_purge_txn

svn_fs_txn_name = _fs.svn_fs_txn_name

svn_fs_txn_base_revision = _fs.svn_fs_txn_base_revision

svn_fs_open_txn = _fs.svn_fs_open_txn

svn_fs_list_transactions = _fs.svn_fs_list_transactions

svn_fs_txn_prop = _fs.svn_fs_txn_prop

svn_fs_txn_proplist = _fs.svn_fs_txn_proplist

svn_fs_change_txn_prop = _fs.svn_fs_change_txn_prop

svn_fs_revision_root = _fs.svn_fs_revision_root

svn_fs_txn_root = _fs.svn_fs_txn_root

svn_fs_close_root = _fs.svn_fs_close_root

svn_fs_root_fs = _fs.svn_fs_root_fs

svn_fs_is_txn_root = _fs.svn_fs_is_txn_root

svn_fs_is_revision_root = _fs.svn_fs_is_revision_root

svn_fs_txn_root_name = _fs.svn_fs_txn_root_name

svn_fs_revision_root_revision = _fs.svn_fs_revision_root_revision
svn_fs_path_change_modify = _fs.svn_fs_path_change_modify
svn_fs_path_change_add = _fs.svn_fs_path_change_add
svn_fs_path_change_delete = _fs.svn_fs_path_change_delete
svn_fs_path_change_replace = _fs.svn_fs_path_change_replace
svn_fs_path_change_reset = _fs.svn_fs_path_change_reset
class svn_fs_path_change_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_fs_path_change_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_fs_path_change_t, name)
    def __init__(self): raise RuntimeError, "No constructor defined"
    def __repr__(self):
        return "<C svn_fs_path_change_t instance at %s>" % (self.this,)
    __swig_setmethods__["node_rev_id"] = _fs.svn_fs_path_change_t_node_rev_id_set
    __swig_getmethods__["node_rev_id"] = _fs.svn_fs_path_change_t_node_rev_id_get
    if _newclass:node_rev_id = property(_fs.svn_fs_path_change_t_node_rev_id_get, _fs.svn_fs_path_change_t_node_rev_id_set)
    __swig_setmethods__["change_kind"] = _fs.svn_fs_path_change_t_change_kind_set
    __swig_getmethods__["change_kind"] = _fs.svn_fs_path_change_t_change_kind_get
    if _newclass:change_kind = property(_fs.svn_fs_path_change_t_change_kind_get, _fs.svn_fs_path_change_t_change_kind_set)
    __swig_setmethods__["text_mod"] = _fs.svn_fs_path_change_t_text_mod_set
    __swig_getmethods__["text_mod"] = _fs.svn_fs_path_change_t_text_mod_get
    if _newclass:text_mod = property(_fs.svn_fs_path_change_t_text_mod_get, _fs.svn_fs_path_change_t_text_mod_set)
    __swig_setmethods__["prop_mod"] = _fs.svn_fs_path_change_t_prop_mod_set
    __swig_getmethods__["prop_mod"] = _fs.svn_fs_path_change_t_prop_mod_get
    if _newclass:prop_mod = property(_fs.svn_fs_path_change_t_prop_mod_get, _fs.svn_fs_path_change_t_prop_mod_set)

class svn_fs_path_change_tPtr(svn_fs_path_change_t):
    def __init__(self, this):
        _swig_setattr(self, svn_fs_path_change_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_fs_path_change_t, 'thisown', 0)
        _swig_setattr(self, svn_fs_path_change_t,self.__class__,svn_fs_path_change_t)
_fs.svn_fs_path_change_t_swigregister(svn_fs_path_change_tPtr)


svn_fs_paths_changed = _fs.svn_fs_paths_changed

svn_fs_check_path = _fs.svn_fs_check_path

svn_fs_node_history = _fs.svn_fs_node_history

svn_fs_history_prev = _fs.svn_fs_history_prev

svn_fs_history_location = _fs.svn_fs_history_location

svn_fs_is_dir = _fs.svn_fs_is_dir

svn_fs_is_file = _fs.svn_fs_is_file

svn_fs_node_id = _fs.svn_fs_node_id

svn_fs_node_created_rev = _fs.svn_fs_node_created_rev

svn_fs_node_created_path = _fs.svn_fs_node_created_path

svn_fs_node_prop = _fs.svn_fs_node_prop

svn_fs_node_proplist = _fs.svn_fs_node_proplist

svn_fs_change_node_prop = _fs.svn_fs_change_node_prop

svn_fs_props_changed = _fs.svn_fs_props_changed

svn_fs_copied_from = _fs.svn_fs_copied_from

svn_fs_merge = _fs.svn_fs_merge
class svn_fs_dirent_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_fs_dirent_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_fs_dirent_t, name)
    def __init__(self): raise RuntimeError, "No constructor defined"
    def __repr__(self):
        return "<C svn_fs_dirent_t instance at %s>" % (self.this,)
    __swig_setmethods__["name"] = _fs.svn_fs_dirent_t_name_set
    __swig_getmethods__["name"] = _fs.svn_fs_dirent_t_name_get
    if _newclass:name = property(_fs.svn_fs_dirent_t_name_get, _fs.svn_fs_dirent_t_name_set)
    __swig_setmethods__["id"] = _fs.svn_fs_dirent_t_id_set
    __swig_getmethods__["id"] = _fs.svn_fs_dirent_t_id_get
    if _newclass:id = property(_fs.svn_fs_dirent_t_id_get, _fs.svn_fs_dirent_t_id_set)
    __swig_setmethods__["kind"] = _fs.svn_fs_dirent_t_kind_set
    __swig_getmethods__["kind"] = _fs.svn_fs_dirent_t_kind_get
    if _newclass:kind = property(_fs.svn_fs_dirent_t_kind_get, _fs.svn_fs_dirent_t_kind_set)

class svn_fs_dirent_tPtr(svn_fs_dirent_t):
    def __init__(self, this):
        _swig_setattr(self, svn_fs_dirent_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_fs_dirent_t, 'thisown', 0)
        _swig_setattr(self, svn_fs_dirent_t,self.__class__,svn_fs_dirent_t)
_fs.svn_fs_dirent_t_swigregister(svn_fs_dirent_tPtr)


svn_fs_dir_entries = _fs.svn_fs_dir_entries

svn_fs_make_dir = _fs.svn_fs_make_dir

svn_fs_delete = _fs.svn_fs_delete

svn_fs_copy = _fs.svn_fs_copy

svn_fs_revision_link = _fs.svn_fs_revision_link

svn_fs_file_length = _fs.svn_fs_file_length

svn_fs_file_md5_checksum = _fs.svn_fs_file_md5_checksum

svn_fs_file_contents = _fs.svn_fs_file_contents

svn_fs_make_file = _fs.svn_fs_make_file

svn_fs_apply_textdelta = _fs.svn_fs_apply_textdelta

svn_fs_apply_text = _fs.svn_fs_apply_text

svn_fs_contents_changed = _fs.svn_fs_contents_changed

svn_fs_youngest_rev = _fs.svn_fs_youngest_rev

svn_fs_deltify_revision = _fs.svn_fs_deltify_revision

svn_fs_revision_prop = _fs.svn_fs_revision_prop

svn_fs_revision_proplist = _fs.svn_fs_revision_proplist

svn_fs_change_rev_prop = _fs.svn_fs_change_rev_prop

svn_fs_get_file_delta_stream = _fs.svn_fs_get_file_delta_stream

svn_fs_get_uuid = _fs.svn_fs_get_uuid

svn_fs_set_uuid = _fs.svn_fs_set_uuid

==> py-subversion-1.2.1.tgz: lib/python2.3/site-packages/libsvn/fs.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _fs

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


import delta

svn_fs_version = _fs.svn_fs_version
SVN_FS_CONFIG_BDB_TXN_NOSYNC = _fs.SVN_FS_CONFIG_BDB_TXN_NOSYNC
SVN_FS_CONFIG_BDB_LOG_AUTOREMOVE = _fs.SVN_FS_CONFIG_BDB_LOG_AUTOREMOVE
SVN_FS_CONFIG_FS_TYPE = _fs.SVN_FS_CONFIG_FS_TYPE
SVN_FS_TYPE_BDB = _fs.SVN_FS_TYPE_BDB
SVN_FS_TYPE_FSFS = _fs.SVN_FS_TYPE_FSFS

svn_fs_initialize = _fs.svn_fs_initialize

svn_fs_set_warning_func = _fs.svn_fs_set_warning_func

svn_fs_create = _fs.svn_fs_create

svn_fs_open = _fs.svn_fs_open

svn_fs_path = _fs.svn_fs_path

svn_fs_delete_fs = _fs.svn_fs_delete_fs

svn_fs_hotcopy = _fs.svn_fs_hotcopy

svn_fs_set_berkeley_errcall = _fs.svn_fs_set_berkeley_errcall

svn_fs_berkeley_recover = _fs.svn_fs_berkeley_recover

svn_fs_berkeley_logfiles = _fs.svn_fs_berkeley_logfiles

svn_fs_new = _fs.svn_fs_new

svn_fs_create_berkeley = _fs.svn_fs_create_berkeley

svn_fs_open_berkeley = _fs.svn_fs_open_berkeley

svn_fs_berkeley_path = _fs.svn_fs_berkeley_path

svn_fs_delete_berkeley = _fs.svn_fs_delete_berkeley

svn_fs_hotcopy_berkeley = _fs.svn_fs_hotcopy_berkeley

svn_fs_create_access = _fs.svn_fs_create_access

svn_fs_set_access = _fs.svn_fs_set_access

svn_fs_get_access = _fs.svn_fs_get_access

svn_fs_access_get_username = _fs.svn_fs_access_get_username

svn_fs_access_add_lock_token = _fs.svn_fs_access_add_lock_token

svn_fs_compare_ids = _fs.svn_fs_compare_ids

svn_fs_check_related = _fs.svn_fs_check_related

svn_fs_parse_id = _fs.svn_fs_parse_id

svn_fs_unparse_id = _fs.svn_fs_unparse_id
SVN_FS_TXN_CHECK_OOD = _fs.SVN_FS_TXN_CHECK_OOD
SVN_FS_TXN_CHECK_LOCKS = _fs.SVN_FS_TXN_CHECK_LOCKS

svn_fs_begin_txn2 = _fs.svn_fs_begin_txn2

svn_fs_begin_txn = _fs.svn_fs_begin_txn

svn_fs_commit_txn = _fs.svn_fs_commit_txn

svn_fs_abort_txn = _fs.svn_fs_abort_txn

svn_fs_purge_txn = _fs.svn_fs_purge_txn

svn_fs_txn_name = _fs.svn_fs_txn_name

svn_fs_txn_base_revision = _fs.svn_fs_txn_base_revision

svn_fs_open_txn = _fs.svn_fs_open_txn

svn_fs_list_transactions = _fs.svn_fs_list_transactions

svn_fs_txn_prop = _fs.svn_fs_txn_prop

svn_fs_txn_proplist = _fs.svn_fs_txn_proplist

svn_fs_change_txn_prop = _fs.svn_fs_change_txn_prop

svn_fs_revision_root = _fs.svn_fs_revision_root

svn_fs_txn_root = _fs.svn_fs_txn_root

svn_fs_close_root = _fs.svn_fs_close_root

svn_fs_root_fs = _fs.svn_fs_root_fs

svn_fs_is_txn_root = _fs.svn_fs_is_txn_root

svn_fs_is_revision_root = _fs.svn_fs_is_revision_root

svn_fs_txn_root_name = _fs.svn_fs_txn_root_name

svn_fs_revision_root_revision = _fs.svn_fs_revision_root_revision
svn_fs_path_change_modify = _fs.svn_fs_path_change_modify
svn_fs_path_change_add = _fs.svn_fs_path_change_add
svn_fs_path_change_delete = _fs.svn_fs_path_change_delete
svn_fs_path_change_replace = _fs.svn_fs_path_change_replace
svn_fs_path_change_reset = _fs.svn_fs_path_change_reset
class svn_fs_path_change_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_fs_path_change_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_fs_path_change_t, name)
    def __init__(self): raise RuntimeError, "No constructor defined"
    def __repr__(self):
        return "<%s.%s; proxy of C svn_fs_path_change_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["node_rev_id"] = _fs.svn_fs_path_change_t_node_rev_id_set
    __swig_getmethods__["node_rev_id"] = _fs.svn_fs_path_change_t_node_rev_id_get
    if _newclass:node_rev_id = property(_fs.svn_fs_path_change_t_node_rev_id_get, _fs.svn_fs_path_change_t_node_rev_id_set)
    __swig_setmethods__["change_kind"] = _fs.svn_fs_path_change_t_change_kind_set
    __swig_getmethods__["change_kind"] = _fs.svn_fs_path_change_t_change_kind_get
    if _newclass:change_kind = property(_fs.svn_fs_path_change_t_change_kind_get, _fs.svn_fs_path_change_t_change_kind_set)
    __swig_setmethods__["text_mod"] = _fs.svn_fs_path_change_t_text_mod_set
    __swig_getmethods__["text_mod"] = _fs.svn_fs_path_change_t_text_mod_get
    if _newclass:text_mod = property(_fs.svn_fs_path_change_t_text_mod_get, _fs.svn_fs_path_change_t_text_mod_set)
    __swig_setmethods__["prop_mod"] = _fs.svn_fs_path_change_t_prop_mod_set
    __swig_getmethods__["prop_mod"] = _fs.svn_fs_path_change_t_prop_mod_get
    if _newclass:prop_mod = property(_fs.svn_fs_path_change_t_prop_mod_get, _fs.svn_fs_path_change_t_prop_mod_set)

class svn_fs_path_change_tPtr(svn_fs_path_change_t):
    def __init__(self, this):
        _swig_setattr(self, svn_fs_path_change_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_fs_path_change_t, 'thisown', 0)
        _swig_setattr(self, svn_fs_path_change_t,self.__class__,svn_fs_path_change_t)
_fs.svn_fs_path_change_t_swigregister(svn_fs_path_change_tPtr)


svn_fs_paths_changed = _fs.svn_fs_paths_changed

svn_fs_check_path = _fs.svn_fs_check_path

svn_fs_node_history = _fs.svn_fs_node_history

svn_fs_history_prev = _fs.svn_fs_history_prev

svn_fs_history_location = _fs.svn_fs_history_location

svn_fs_is_dir = _fs.svn_fs_is_dir

svn_fs_is_file = _fs.svn_fs_is_file

svn_fs_node_id = _fs.svn_fs_node_id

svn_fs_node_created_rev = _fs.svn_fs_node_created_rev

svn_fs_node_created_path = _fs.svn_fs_node_created_path

svn_fs_node_prop = _fs.svn_fs_node_prop

svn_fs_node_proplist = _fs.svn_fs_node_proplist

svn_fs_change_node_prop = _fs.svn_fs_change_node_prop

svn_fs_props_changed = _fs.svn_fs_props_changed

svn_fs_copied_from = _fs.svn_fs_copied_from

svn_fs_merge = _fs.svn_fs_merge
class svn_fs_dirent_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_fs_dirent_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_fs_dirent_t, name)
    def __init__(self): raise RuntimeError, "No constructor defined"
    def __repr__(self):
        return "<%s.%s; proxy of C svn_fs_dirent_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["name"] = _fs.svn_fs_dirent_t_name_set
    __swig_getmethods__["name"] = _fs.svn_fs_dirent_t_name_get
    if _newclass:name = property(_fs.svn_fs_dirent_t_name_get, _fs.svn_fs_dirent_t_name_set)
    __swig_setmethods__["id"] = _fs.svn_fs_dirent_t_id_set
    __swig_getmethods__["id"] = _fs.svn_fs_dirent_t_id_get
    if _newclass:id = property(_fs.svn_fs_dirent_t_id_get, _fs.svn_fs_dirent_t_id_set)
    __swig_setmethods__["kind"] = _fs.svn_fs_dirent_t_kind_set
    __swig_getmethods__["kind"] = _fs.svn_fs_dirent_t_kind_get
    if _newclass:kind = property(_fs.svn_fs_dirent_t_kind_get, _fs.svn_fs_dirent_t_kind_set)

class svn_fs_dirent_tPtr(svn_fs_dirent_t):
    def __init__(self, this):
        _swig_setattr(self, svn_fs_dirent_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_fs_dirent_t, 'thisown', 0)
        _swig_setattr(self, svn_fs_dirent_t,self.__class__,svn_fs_dirent_t)
_fs.svn_fs_dirent_t_swigregister(svn_fs_dirent_tPtr)


svn_fs_dir_entries = _fs.svn_fs_dir_entries

svn_fs_make_dir = _fs.svn_fs_make_dir

svn_fs_delete = _fs.svn_fs_delete

svn_fs_copy = _fs.svn_fs_copy

svn_fs_revision_link = _fs.svn_fs_revision_link

svn_fs_file_length = _fs.svn_fs_file_length

svn_fs_file_md5_checksum = _fs.svn_fs_file_md5_checksum

svn_fs_file_contents = _fs.svn_fs_file_contents

svn_fs_make_file = _fs.svn_fs_make_file

svn_fs_apply_textdelta = _fs.svn_fs_apply_textdelta

svn_fs_apply_text = _fs.svn_fs_apply_text

svn_fs_contents_changed = _fs.svn_fs_contents_changed

svn_fs_youngest_rev = _fs.svn_fs_youngest_rev

svn_fs_deltify_revision = _fs.svn_fs_deltify_revision

svn_fs_revision_prop = _fs.svn_fs_revision_prop

svn_fs_revision_proplist = _fs.svn_fs_revision_proplist

svn_fs_change_rev_prop = _fs.svn_fs_change_rev_prop

svn_fs_get_file_delta_stream = _fs.svn_fs_get_file_delta_stream

svn_fs_get_uuid = _fs.svn_fs_get_uuid

svn_fs_set_uuid = _fs.svn_fs_set_uuid

svn_fs_lock = _fs.svn_fs_lock

svn_fs_generate_lock_token = _fs.svn_fs_generate_lock_token

svn_fs_unlock = _fs.svn_fs_unlock

svn_fs_get_lock = _fs.svn_fs_get_lock

svn_fs_get_locks = _fs.svn_fs_get_locks

svn_fs_print_modules = _fs.svn_fs_print_modules
